(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     77092,       2044]
NotebookOptionsPosition[     70319,       1924]
NotebookOutlinePosition[     70717,       1940]
CellTagsIndexPosition[     70674,       1937]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Complex scaling of the \[OpenCurlyDoubleQuote]screened \
P\[ODoubleDot]schl-Teller\[CloseCurlyDoubleQuote] potential", "Title",
 CellChangeTimes->{{3.83991181728601*^9, 
  3.839911853178388*^9}},ExpressionUUID->"62ebb54d-6d01-4714-8bde-\
6b65eb5d9a46"],

Cell["Niels Walet, University of Manchester, September 2021", "Subtitle",
 CellChangeTimes->{{3.8399118578741293`*^9, 3.8399118667703133`*^9}, {
  3.839933229625751*^9, 
  3.839933236225658*^9}},ExpressionUUID->"c6b7f60e-4d58-483a-b801-\
02770af1e00c"],

Cell[TextData[{
 "This notebook calculates the spectrum of the Hamiltonian ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    SuperscriptBox["p", "2"], "2"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"Cosh", "[", "x", "]"}], "2"]]}], ")"}], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], " ", 
      SuperscriptBox["x", "2"]}]]}]}]], "Input",
  CellChangeTimes->{{3.8395169543268757`*^9, 3.839516958385838*^9}, {
    3.8395170007656612`*^9, 3.839517018386384*^9}, 3.839517361546372*^9},
  ExpressionUUID->"fbeb2d2f-928d-4c9d-941c-af7339f958f6"],
 " for complex scaled radii."
}], "Text",
 CellChangeTimes->{{3.83993313751691*^9, 
  3.839933223997995*^9}},ExpressionUUID->"1f1c5421-28fb-483f-bb02-\
4dc99bd6b04e"],

Cell[CellGroupData[{

Cell["Harmonic oscillator basis", "Section",
 CellChangeTimes->{{3.8273063790543203`*^9, 
  3.8273063931019773`*^9}},ExpressionUUID->"8e81c612-c136-4c4b-b0d7-\
b730fa7a38f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"n_", ",", "x_", ",", 
    RowBox[{"b_", ":", "1"}]}], "]"}], "=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["\[Pi]", 
      RowBox[{"1", "/", "4"}]], 
     SqrtBox[
      RowBox[{"b", " ", 
       SuperscriptBox["2", "n"], 
       RowBox[{"n", "!"}]}]]}]], 
   RowBox[{"HermiteH", "[", 
    RowBox[{"n", ",", 
     RowBox[{"x", "/", "b"}]}], "]"}], " ", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["x", "2"]}], "/", 
      SuperscriptBox["b", "2"]}], "/", "2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.827206662004548*^9, 3.8272067303962*^9}, {
  3.8272068588445873`*^9, 3.827206904010157*^9}, {3.827206960754965*^9, 
  3.827206960922327*^9}, {3.827230064398238*^9, 3.827230093969673*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"2236accd-f04b-435a-b0be-1260b4af2428"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["x", "2"], 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"]}]]}]], " ", 
   RowBox[{"HermiteH", "[", 
    RowBox[{"n", ",", 
     FractionBox["x", "b"]}], "]"}]}], 
  RowBox[{
   SuperscriptBox["\[Pi]", 
    RowBox[{"1", "/", "4"}]], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["2", "n"], " ", "b", " ", 
     RowBox[{"n", "!"}]}]]}]]], "Output",
 CellChangeTimes->{{3.827206873612033*^9, 3.827206904393485*^9}, 
   3.827206961540756*^9, 3.8272275292183*^9, {3.827230115543693*^9, 
   3.827230134238694*^9}, 3.8272313347695*^9, 3.827314845595158*^9, 
   3.8275792864079857`*^9, 3.827770892307827*^9, 3.827906150985365*^9, 
   3.8279376393899927`*^9, 3.829151747434443*^9, 3.830272761552903*^9, 
   3.830336657159596*^9, 3.8305125195934353`*^9, 3.830595566647056*^9, 
   3.8335209349291573`*^9, 3.833527041853711*^9, 3.83394211020858*^9, 
   3.834418489476221*^9, 3.839516538003706*^9, 3.839517450253623*^9, 
   3.8395578532416697`*^9, 3.839580047892332*^9, {3.8399115662746153`*^9, 
   3.839911586298728*^9}},
 CellLabel->"Out[1]=",ExpressionUUID->"27324179-7abd-4b0e-80d2-847ff0631a19"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quick calculation of matrix elements", "Subsection",
 CellChangeTimes->{{3.827306503491068*^9, 
  3.827306513799108*^9}},ExpressionUUID->"d0ba49e5-727d-40fc-a782-\
09f955d4ba9b"],

Cell["Use generating function", "Text",
 CellChangeTimes->{{3.8272099679393682`*^9, 
  3.8272099722755136`*^9}},ExpressionUUID->"b1111201-90a1-4a23-afd4-\
d54cb601910c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"x", "^", "2"}]}], "+", 
     RowBox[{"2", "x", " ", "t"}], " ", "-", 
     RowBox[{"t", "^", "2"}], "+", 
     RowBox[{"2", "x", " ", "s"}], " ", "-", 
     RowBox[{"s", "^", "2"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.82721005722064*^9, 3.827210107373145*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"1e42b9c5-0e8b-4a98-9ffb-536725070328"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", "s", " ", "t"}]], " ", 
  SqrtBox["\[Pi]"]}]], "Output",
 CellChangeTimes->{{3.8272100895074797`*^9, 3.8272101090907087`*^9}, 
   3.827230135323497*^9, 3.827231335270138*^9, 3.8273148470660343`*^9, 
   3.8275792875532846`*^9, 3.827906152164941*^9, 3.827937640543086*^9, 
   3.829151748578918*^9, 3.830272762709392*^9, 3.8303366582814817`*^9, 
   3.8305125206981287`*^9, 3.8305955677780437`*^9, 3.833520936025037*^9, 
   3.833527042962228*^9, 3.8339421113599987`*^9, 3.8344184906300917`*^9, 
   3.8395800493868027`*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"c05781cc-30cf-46ad-b672-f5eb1bde3ac2"]
}, Open  ]],

Cell[TextData[{
 "So ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     SuperscriptBox["2", 
      RowBox[{"n", " "}]], 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", "st", ")"}], "n"]}], TraditionalForm]],ExpressionUUID->
  "d7ae4e16-9ae9-4f6c-ad92-4b8c4f407f69"],
 ". This shows that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{"n", "|", "m"}], "\[RightAngleBracket]"}], "=", 
    SubscriptBox["\[Delta]", 
     RowBox[{"n", ",", "m"}]]}], TraditionalForm]],ExpressionUUID->
  "82751d26-a715-4492-832b-ddf9ce301b0e"]
}], "Text",
 CellChangeTimes->{{3.82722338952486*^9, 
  3.827223477762092*^9}},ExpressionUUID->"437904fb-95e7-4b53-a4c2-\
7062e676bc2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "^", "2"}]}], "/", "2"}], "+", 
        RowBox[{"2", "x", " ", "t"}], " ", "-", 
        RowBox[{"t", "^", "2"}]}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], "/", "2"}], "+", 
        RowBox[{"2", "x", " ", "s"}], " ", "-", 
        RowBox[{"s", "^", "2"}]}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.827210124809144*^9, 3.8272101930339813`*^9}, {
  3.827210323011509*^9, 3.827210323331031*^9}, {3.827210452408668*^9, 
  3.82721045326392*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7e0aaa1a-c545-4507-b84b-e840fb396b13"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", "s", " ", "t"}]], " ", 
  SqrtBox["\[Pi]"], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"s", "-", "t"}], ")"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.827210176753636*^9, 3.827210200036685*^9}, 
   3.827210329834621*^9, 3.827210460098567*^9, 3.827230140538509*^9, 
   3.827231336451539*^9, 3.8273148521251917`*^9, 3.827579292597767*^9, 
   3.827906157402615*^9, 3.827937645749981*^9, 3.829151753893449*^9, 
   3.830272768133881*^9, 3.8303366633868628`*^9, 3.8305125258763943`*^9, 
   3.830595572915339*^9, 3.833520941179678*^9, 3.8335270480992603`*^9, 
   3.833942116471046*^9, 3.834418495775999*^9, 3.839580054900217*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"7f506e7f-12a2-4c88-b578-c56fc52057a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], 
     FractionBox[
      RowBox[{
       RowBox[{"2", "^", "n"}], " "}], 
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]], 
     SqrtBox[
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"n", "+", "2"}], ")"}]}], "/", "2"}]], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "2"}], ")"}], "!"}]], 
     RowBox[{"ExpandAll", "[", 
      RowBox[{
       RowBox[{"s", "^", "n"}], " ", 
       RowBox[{"t", "^", "n"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", "s", " ", "t"}], "-", 
           RowBox[{"2", 
            RowBox[{"s", "^", "2"}]}], "-", 
           RowBox[{"2", 
            RowBox[{"t", "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"s", "^", "n"}]}], "/", 
        RowBox[{"t", "^", 
         RowBox[{"(", 
          RowBox[{"n", "+", "2"}], ")"}]}]}]}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", "0"}], ",", 
      RowBox[{"t", "\[Rule]", "\[Infinity]"}]}], "}"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"n", "\[Element]", "PositiveIntegers"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827223916891313*^9, 3.82722405911506*^9}, {
  3.827224103148596*^9, 3.827224206808444*^9}, {3.8272243011823683`*^9, 
  3.8272244688105583`*^9}, {3.8272245086796217`*^9, 3.827224635681896*^9}, {
  3.8272246796058197`*^9, 3.827224685093145*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"efde600d-4a96-4c9c-bf29-2f1b05404f73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "n"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "n"}], ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.8272243953691063`*^9, {3.827224440867601*^9, 3.827224469462552*^9}, 
   3.827224539597785*^9, {3.827224581242394*^9, 3.8272245954451857`*^9}, 
   3.827224638172271*^9, 3.827224685896738*^9, 3.827230140665245*^9, 
   3.8272313365704412`*^9, 3.827314852210649*^9, 3.8275792926909523`*^9, 
   3.8279061575624104`*^9, 3.8279376459288588`*^9, 3.829151754035778*^9, 
   3.83027276823166*^9, 3.830336663495967*^9, 3.830512525953948*^9, 
   3.830595573089491*^9, 3.833520941346949*^9, 3.8335270481917048`*^9, 
   3.833942116598032*^9, 3.834418495948105*^9, 3.839580055049549*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"e6c69685-97d9-4b70-a14d-57f9c3adfbb2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"int", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    FractionBox["1", "4"], 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", "n"}], "/", "2"}]], 
    SqrtBox[
     RowBox[{"n", "!"}]], 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", "n", ")"}]}], "/", "2"}]], 
    SqrtBox[
     RowBox[{
      RowBox[{"(", "n", ")"}], "!"}]], 
    RowBox[{"ExpandAll", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", "^", "n"}], " "}], 
           RowBox[{"n", "!"}]], 
          RowBox[{"s", "^", "n"}], " ", 
          RowBox[{"t", "^", "n"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", "s", " ", "t"}], "-", 
            RowBox[{"2", 
             RowBox[{"s", "^", "2"}]}], "-", 
            RowBox[{"2", 
             RowBox[{"t", "^", "2"}]}]}], ")"}]}], "+", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"n", "-", "1"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "1"}], ")"}], "!"}]], 
          RowBox[{"s", "^", 
           RowBox[{"(", 
            RowBox[{"n", "-", "1"}], ")"}]}], " ", 
          RowBox[{"t", "^", 
           RowBox[{"(", 
            RowBox[{"n", "-", "1"}], ")"}]}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", "s", " ", "t"}], "-", 
            RowBox[{"2", 
             RowBox[{"s", "^", "2"}]}], "-", 
            RowBox[{"2", 
             RowBox[{"t", "^", "2"}]}]}], ")"}]}]}], ")"}], "/", 
       RowBox[{"s", "^", "n"}]}], "/", 
      RowBox[{"t", "^", 
       RowBox[{"(", "n", ")"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8272247049843273`*^9, 3.827224815766083*^9}, {
  3.8272248460116158`*^9, 3.8272249388071537`*^9}, {3.827225037595715*^9, 
  3.827225040075316*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"8fc47b2a-a884-4069-a09a-5867aebfb52f"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["s", "2"]}], "-", 
      RowBox[{"2", " ", "s", " ", "t"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["t", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "s", " ", "t", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "n"}], ")"}], "!"}]}], "+", 
      RowBox[{"n", "!"}]}], ")"}]}], 
   RowBox[{"8", " ", "s", " ", "t", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "n"}], ")"}], "!"}]}]]}]], "Output",
 CellChangeTimes->{{3.827224882178917*^9, 3.8272249393316402`*^9}, 
   3.8272250413315287`*^9, 3.827230140693645*^9, 3.827231336603118*^9, 
   3.827314852232551*^9, 3.827579292730598*^9, 3.8279061576242237`*^9, 
   3.827937645995412*^9, 3.829151754108452*^9, 3.830272768276716*^9, 
   3.830336663528572*^9, 3.8305125259822702`*^9, 3.8305955731365757`*^9, 
   3.8335209413844547`*^9, 3.833527048222831*^9, 3.833942116648159*^9, 
   3.834418496005422*^9, 3.83958005507555*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"2078d1ae-369f-42b6-8a61-29f42a11ec22"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Numerator", "[", "int", "]"}], ",", 
      RowBox[{"s", " ", "t"}]}], "]"}], " ", "s", " ", 
    RowBox[{"t", " ", "/", 
     RowBox[{"Denominator", "[", "int", "]"}]}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"n", "\[Element]", "PositiveIntegers"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827224943623724*^9, 3.8272250775851*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"1151d836-2f52-4ddb-8ae9-87924068ff39"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "+", "n"}], "4"]], "Output",
 CellChangeTimes->{3.8272250781385803`*^9, 3.8272301407213087`*^9, 
  3.827231336635703*^9, 3.82731485225347*^9, 3.827579292772479*^9, 
  3.82790615768883*^9, 3.8279376460654707`*^9, 3.82915175418559*^9, 
  3.830272768322072*^9, 3.830336663568699*^9, 3.830512526013255*^9, 
  3.830595573185647*^9, 3.8335209414235353`*^9, 3.8335270482698174`*^9, 
  3.833942116701518*^9, 3.834418496064084*^9, 3.839580055096127*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"d5222f4d-bcb7-45f4-8d7e-c653a2607ae8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], 
     FractionBox[
      RowBox[{"2", "^", 
       RowBox[{"(", 
        RowBox[{"n", "-", "2"}], ")"}], " "}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "2"}], ")"}], "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]], 
     SqrtBox[
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"n", "-", "2"}], ")"}]}], "/", "2"}]], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "2"}], ")"}], "!"}]], 
     RowBox[{"ExpandAll", "[", 
      RowBox[{
       RowBox[{"s", "^", 
        RowBox[{"(", 
         RowBox[{"n", "-", "2"}], ")"}]}], " ", 
       RowBox[{"t", "^", 
        RowBox[{"(", 
         RowBox[{"n", "-", "2"}], ")"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", "s", " ", "t"}], "-", 
           RowBox[{"2", 
            RowBox[{"s", "^", "2"}]}], "-", 
           RowBox[{"2", 
            RowBox[{"t", "^", "2"}]}]}], ")"}], "/", 
         RowBox[{"s", "^", "n"}]}], "/", 
        RowBox[{"t", "^", 
         RowBox[{"(", 
          RowBox[{"n", "-", "2"}], ")"}]}]}]}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", "\[Infinity]"}], ",", 
      RowBox[{"t", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"n", "\[Element]", "PositiveIntegers"}], "\[And]", " ", 
     RowBox[{"n", ">", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8272249216038637`*^9, 3.827224923821697*^9}, {
  3.827225091551546*^9, 3.827225202585202*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"6b5e1311-f7e7-4649-88a3-0766b9792420"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", "n"}]]}]], "Output",
 CellChangeTimes->{3.827225203224319*^9, 3.827230140764811*^9, 
  3.827231336682427*^9, 3.827314852294376*^9, 3.827579292816677*^9, 
  3.827906157756138*^9, 3.827937646139462*^9, 3.829151754260923*^9, 
  3.830272768379498*^9, 3.83033666361235*^9, 3.830512526057411*^9, 
  3.830595573235998*^9, 3.833520941464752*^9, 3.8335270483144217`*^9, 
  3.833942116754869*^9, 3.834418496128134*^9, 3.839580055137938*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"24b4657f-ca85-4e1f-a3a3-3180c303158e"]
}, Open  ]],

Cell[TextData[{
 "So ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "4"], TraditionalForm]],ExpressionUUID->
  "3c56eae4-4ab7-4caf-9f2b-e6e15131031a"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     SuperscriptBox["2", 
      RowBox[{"n", " "}]], 
     RowBox[{"n", "!"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"s", " ", "t"}], ")"}], "n"]}], TraditionalForm]],
  ExpressionUUID->"9ef1227b-28e4-46e3-a66d-45cf2ca36aa8"],
 "(1+2st ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"s", "^", "2"}]}], "-", 
    RowBox[{"2", 
     SuperscriptBox["t", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "792e3bf7-8a52-4c41-a8ad-45678ea85165"],
 ").\[LineSeparator]So ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{"n", "|", 
      SuperscriptBox["p", "2"], "|", "m"}], "\[RightAngleBracket]"}], "=", 
    TagBox[GridBox[{
       {"\[Piecewise]", GridBox[{
          {GridBox[{
             {
              RowBox[{
               FractionBox["1", "4"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", "n"}], "+", "1"}], ")"}]}]}
            }], 
           RowBox[{"n", "=", "m"}]},
          {
           RowBox[{
            FractionBox[
             RowBox[{"-", "1"}], "4"], 
            SqrtBox[
             RowBox[{"n", "(", 
              RowBox[{"n", "-", "1"}], ")"}]]}], 
           RowBox[{"m", "=", 
            RowBox[{"n", "-", "2"}]}]},
          {
           RowBox[{
            FractionBox[
             RowBox[{"-", "1"}], "4"], 
            SqrtBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", "1"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"n", "+", "2"}], ")"}]}]]}], 
           RowBox[{"m", "=", 
            RowBox[{"n", "+", "2"}]}]}
         },
         AllowedDimensions->{2, Automatic},
         Editable->True,
         GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
         GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.84]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}},
         Selectable->True]}
      },
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.35]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}],
     "Piecewise",
     DeleteWithContents->True,
     Editable->False,
     SelectWithContents->True,
     Selectable->False,
     StripWrapperBoxes->True]}], TraditionalForm]],ExpressionUUID->
  "7defa9f1-49a5-43e3-8087-b6a02d48e4ad"]
}], "Text",
 CellChangeTimes->{{3.827223489483046*^9, 3.827223628547645*^9}, {
  3.8272236612879753`*^9, 3.8272237229289722`*^9}, {3.8272237554552717`*^9, 
  3.827223768561109*^9}, {3.827223892045574*^9, 3.8272239276342993`*^9}, {
  3.827225214569599*^9, 
  3.827225248637033*^9}},ExpressionUUID->"b3a84ff0-4556-4131-85a7-\
f7a9f3efbfd8"],

Cell["x matrix element", "Text",
 CellChangeTimes->{{3.827228465115219*^9, 
  3.82722846796356*^9}},ExpressionUUID->"7004126b-0b7e-4cd1-b2f0-\
0607cbb423c6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"x", "^", "2"}]}], "+", 
      RowBox[{"2", "x", " ", "t"}], " ", "-", 
      RowBox[{"t", "^", "2"}], "+", 
      RowBox[{"2", "x", " ", "s"}], " ", "-", 
      RowBox[{"s", "^", "2"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.827228489328189*^9, 3.827228489592203*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"8c5933de-0c93-4773-9f70-f7490c537240"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", "s", " ", "t"}]], " ", 
  SqrtBox["\[Pi]"], " ", 
  RowBox[{"(", 
   RowBox[{"s", "+", "t"}], ")"}]}]], "Output",
 CellChangeTimes->{3.827230156655376*^9, 3.827231352204447*^9, 
  3.827314852985124*^9, 3.827579293510161*^9, 3.827906158469953*^9, 
  3.827937646835018*^9, 3.829151755025838*^9, 3.8302727692020807`*^9, 
  3.8303366643063*^9, 3.830512526755918*^9, 3.8305955739346437`*^9, 
  3.833520942152246*^9, 3.83352704901049*^9, 3.83394211744025*^9, 
  3.834418496863044*^9, 3.839580055888769*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"b311a96f-05b5-410d-9df9-cb9f5e6f03cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", "s", " ", "t"}]], " ", 
  SqrtBox["\[Pi]"], " ", 
  RowBox[{"(", 
   RowBox[{"s", "+", "t"}], ")"}]}]], "Input",
 CellChangeTimes->{3.8272285262462997`*^9},
 CellLabel->"In[9]:=",ExpressionUUID->"f131dad6-f808-43de-895e-d77962cb4b37"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", "s", " ", "t"}]], " ", 
  SqrtBox["\[Pi]"], " ", 
  RowBox[{"(", 
   RowBox[{"s", "+", "t"}], ")"}]}]], "Output",
 CellChangeTimes->{3.8272301566826982`*^9, 3.827231352238389*^9, 
  3.827314853010961*^9, 3.827579293550064*^9, 3.8279061585761766`*^9, 
  3.827937646946493*^9, 3.82915175515234*^9, 3.8302727692541113`*^9, 
  3.830336664347066*^9, 3.830512526785572*^9, 3.8305955740667257`*^9, 
  3.833520942188051*^9, 3.833527049052751*^9, 3.833942117488901*^9, 
  3.834418496986203*^9, 3.8395800559094763`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"b62c248d-224c-4061-b5b8-9a81e38bb0ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", "^", "n"}], " "}], 
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]], 
     SqrtBox[
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}], "/", "2"}]], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], "!"}]], 
     RowBox[{"ExpandAll", "[", 
      RowBox[{
       RowBox[{"s", "^", "n"}], " ", 
       RowBox[{"t", "^", "n"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s", "+", "t"}], ")"}], "/", 
         RowBox[{"s", "^", "n"}]}], "/", 
        RowBox[{"t", "^", 
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}]}]}]}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", "0"}], ",", 
      RowBox[{"t", "\[Rule]", "\[Infinity]"}]}], "}"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"n", "\[Element]", "PositiveIntegers"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827228531817708*^9, 3.827228611314992*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"fcf2ed12-aaff-42f9-8517-1db9d4901afb"],

Cell[BoxData[
 FractionBox[
  SqrtBox[
   RowBox[{"1", "+", "n"}]], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{
  3.827228555693719*^9, {3.8272285879905767`*^9, 3.827228613875389*^9}, 
   3.827230156756291*^9, 3.827231352290392*^9, 3.827314853056096*^9, 
   3.827579293633751*^9, 3.827906158634585*^9, 3.827937647014784*^9, 
   3.829151755255875*^9, 3.830272769305929*^9, 3.83033666439559*^9, 
   3.8305125268559847`*^9, 3.8305955741125593`*^9, 3.8335209423479567`*^9, 
   3.8335270490985937`*^9, 3.833942117603565*^9, 3.834418497042701*^9, 
   3.839580055989353*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"8eaa1ea3-dfba-4f6f-bf36-8ed5bab25b67"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"2", "^", 
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], " "}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}]}], "/", "2"}]], 
     SqrtBox[
      RowBox[{"n", "!"}]], 
     SuperscriptBox["2", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", "n", ")"}]}], "/", "2"}]], 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], "!"}]], 
     RowBox[{"ExpandAll", "[", 
      RowBox[{
       RowBox[{"s", "^", 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}]}], " ", 
       RowBox[{"t", "^", 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}]}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s", "+", "t"}], ")"}], "/", 
         RowBox[{"s", "^", "n"}]}], "/", 
        RowBox[{"t", "^", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}]}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "\[Rule]", "0"}], ",", 
      RowBox[{"s", "\[Rule]", "\[Infinity]"}]}], "}"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"n", "\[Element]", "PositiveIntegers"}], "\[And]", " ", 
     RowBox[{"n", ">", "1"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.827228621825478*^9, 3.827228714294239*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"b152ca7e-a27e-4495-a453-27c4257e4027"],

Cell[BoxData[
 FractionBox[
  SqrtBox["n"], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{{3.8272286770539637`*^9, 3.827228715209592*^9}, 
   3.827230156811429*^9, 3.827231352336154*^9, 3.8273148530970163`*^9, 
   3.827579293727961*^9, 3.8279061587049026`*^9, 3.8279376470886593`*^9, 
   3.829151755357963*^9, 3.830272769354639*^9, 3.8303366645166273`*^9, 
   3.830512526899597*^9, 3.83059557416113*^9, 3.833520942389799*^9, 
   3.8335270491403103`*^9, 3.833942117654245*^9, 3.83441849710526*^9, 
   3.839580056030283*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"be51ffbc-6337-4663-b229-22db4529dcdf"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define matrix elements needed", "Subsection",
 CellChangeTimes->{{3.827306536719366*^9, 
  3.827306543259317*^9}},ExpressionUUID->"bd1a983b-271e-4d66-8e36-\
d29705e49320"],

Cell[TextData[{
 "The Hamiltonian matrix  of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["p", "2"]}], "+", 
     RowBox[{"V", "(", "x", ")"}]}], ")"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "628f828c-1605-4e92-afaf-75c3dbf2526f"],
 " is calculated in a h.osc. basis; elements are calculated using \
Gauss-Hermite integration."
}], "Text",
 CellChangeTimes->{{3.8399116096999083`*^9, 
  3.8399117117448263`*^9}},ExpressionUUID->"92a9f7b9-7c61-4414-bad7-\
ff5b995ea4ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kin", "[", 
   RowBox[{"n_", ",", "m_", ",", 
    RowBox[{"b_", ":", "1"}]}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["b", "2"]], 
        FractionBox["1", "4"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}], ")"}]}], ",", 
       RowBox[{"n", "\[Equal]", "m"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], "4"], 
        FractionBox["1", 
         SuperscriptBox["b", "2"]], 
        SqrtBox[
         RowBox[{"n", "(", 
          RowBox[{"n", "-", "1"}], ")"}]]}], ",", 
       RowBox[{"m", "\[Equal]", 
        RowBox[{"n", "-", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], "4"], 
        FractionBox["1", 
         SuperscriptBox["b", "2"]], 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"n", "+", "2"}], ")"}]}]]}], ",", 
       RowBox[{"m", "\[Equal]", 
        RowBox[{"n", "+", "2"}]}]}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.827227722063505*^9, 3.827227861846601*^9}, {
  3.827229953482703*^9, 3.827229954893126*^9}, {3.8272299882454653`*^9, 
  3.827230007012973*^9}, {3.827230392718068*^9, 3.827230416001616*^9}, {
  3.83951673788447*^9, 3.8395167693601427`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"702ca629-f8e4-4f3a-83dd-abb934ef64fc"],

Cell["\<\
You can lower this without too much of a risk (tested up to 800): it is the \
order of the Gauss hermite integration\
\>", "Text",
 CellChangeTimes->{{3.8399113876780043`*^9, 3.839911414994089*^9}, {
  3.839911716344734*^9, 
  3.8399117334971647`*^9}},ExpressionUUID->"cea0d801-44d8-4868-bc63-\
63d6b7843fa4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hermiteorder", "=", "200"}]], "Input",
 CellChangeTimes->{{3.830596523187976*^9, 3.8305965325019827`*^9}, 
   3.8395173217766323`*^9, {3.839911419570455*^9, 3.83991141985005*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"70948c15-6e07-4712-9b34-51fb63a0d61a"],

Cell[BoxData["200"], "Output",
 CellChangeTimes->{3.830596585495966*^9, 3.833520942578951*^9, 
  3.833521430856059*^9, 3.833527049368681*^9, 3.833942117774276*^9, 
  3.8344184972010183`*^9, 3.8395174573955727`*^9, 3.839557861113554*^9, 
  3.8395800560534563`*^9, 3.839911593578458*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"fae9488f-c63d-4920-8b81-586e9a593866"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroes", "=", 
   RowBox[{"{", 
    RowBox[{"ToRules", "[", 
     RowBox[{"NRoots", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"HermiteH", "[", 
         RowBox[{"hermiteorder", ",", "x"}], "]"}], "\[Equal]", "0"}], ",", 
       "x", ",", 
       RowBox[{"PrecisionGoal", "->", "25"}]}], "]"}], "]"}], "}"}]}], ";", 
  RowBox[{"zerotab", "=", 
   RowBox[{"x", "/.", "zeroes"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.827592189952798*^9, 3.82759227294055*^9}, {
   3.827592398042284*^9, 3.827592408809407*^9}, {3.82759255080363*^9, 
   3.8275925592349243`*^9}, {3.827769729396237*^9, 3.827769776068088*^9}, {
   3.8277699571181707`*^9, 3.827769957501831*^9}, {3.830336582289247*^9, 
   3.8303365842890778`*^9}, 3.830596544386389*^9, 3.839517323881278*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"fae31b6e-a0a6-4e29-8b30-702bc1f47a13"],

Cell[BoxData[
 RowBox[{
  RowBox[{"weights", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", "hermiteorder"}], "}"}], ",", 
     FractionBox[
      SqrtBox["\[Pi]"], 
      RowBox[{"n", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"HermiteH", "[", 
           RowBox[{
            RowBox[{"n", "-", "1"}], ",", "zerotab"}], "]"}], ")"}], "2"], 
        "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"n", "-", "1"}]], 
          RowBox[{"Gamma", "[", "n", "]"}]}], ")"}]}]}]]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8277697995242357`*^9, 3.8277699053618813`*^9}, {
   3.827769947462405*^9, 3.827769948157782*^9}, {3.8303365919456882`*^9, 
   3.830336593456842*^9}, {3.830596511658573*^9, 3.8305965127386303`*^9}, 
   3.83059654761514*^9, 3.8395173263850927`*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"fe017a33-6577-4d7f-8b13-72ab6719fe30"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pot", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"Cosh", "[", "x", "]"}], "2"]]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.05"}], " ", 
     SuperscriptBox["x", "2"]}]]}]}]], "Input",
 CellChangeTimes->{{3.8395169543268757`*^9, 3.839516958385838*^9}, {
   3.8395170007656612`*^9, 3.839517018386384*^9}, 3.839517361546372*^9},
 CellLabel->"In[6]:=",ExpressionUUID->"9671d86d-4fd7-41ab-b498-0719176f2180"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "0.05`"}], " ", 
    SuperscriptBox["x", "2"]}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", 
    SuperscriptBox[
     RowBox[{"Sech", "[", "x", "]"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.839518057753993*^9, 3.839558446654147*^9, 
  3.839580708287096*^9, 3.839911600268211*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"16736475-e0e0-4242-b239-fa7ff08c579f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Attributes", "[", "pot", "]"}], "=", 
   RowBox[{"{", "Listable", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.839516984587256*^9, 3.839517014590205*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"3726e302-2df7-4cad-9a44-0180550503f4"],

Cell["Calculate and diagonalise the Hamiltonian", "Text",
 CellChangeTimes->{{3.839911743614891*^9, 
  3.839911761397646*^9}},ExpressionUUID->"a682d818-6ebb-4a9b-90f0-\
3aa47723dc05"],

Cell[BoxData[
 RowBox[{
  RowBox[{"calcstr2", "[", 
   RowBox[{"b_", ",", "nbasis_", ",", 
    RowBox[{"\[Theta]_", ":", "0"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"h1", ",", 
      RowBox[{"htab", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"HermiteH", "[", 
            RowBox[{"n", ",", "zerotab"}], "]"}], ")"}], "/", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["2", "n"], 
            RowBox[{"Gamma", "[", 
             RowBox[{"n", "+", "1"}], "]"}], 
            SqrtBox["\[Pi]"]}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "nbasis", ",", "2"}], "}"}]}], 
        "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"h1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kin", "[", 
          RowBox[{"n", ",", "m", ",", 
           RowBox[{"b", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}], "]"}], "+", 
         RowBox[{"(", " ", 
          RowBox[{"Plus", "@@", 
           RowBox[{"(", 
            RowBox[{"weights", " ", 
             RowBox[{"htab", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"n", "/", "2"}], "+", "1"}], "]"}], "]"}], 
             RowBox[{"htab", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"m", "/", "2"}], "+", "1"}], "]"}], "]"}], 
             RowBox[{"pot", "[", 
              RowBox[{"b", " ", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", "zerotab"}],
               "]"}]}], ")"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "0", ",", "nbasis", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "nbasis", ",", "2"}], "}"}]}], "]"}]}], 
     ";", 
     RowBox[{"Sort", "[", 
      RowBox[{"Eigenvalues", "[", "h1", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.827921505492852*^9, 3.8279217184513483`*^9}, 
   3.8279222359582767`*^9, {3.827922303205577*^9, 3.827922343762274*^9}, {
   3.827922392134067*^9, 3.827922416914524*^9}, {3.830277744530764*^9, 
   3.830277747994871*^9}, {3.830277785695314*^9, 3.830277811331236*^9}, {
   3.8303577585870733`*^9, 3.830357760724546*^9}, {3.83951666621231*^9, 
   3.839516724452997*^9}, {3.839516774136973*^9, 3.839516782824095*^9}, {
   3.839516832673704*^9, 3.839516864933651*^9}, {3.839516897267642*^9, 
   3.839516947850292*^9}, {3.8395170343153276`*^9, 3.839517061366776*^9}, {
   3.839517107363599*^9, 3.839517159995708*^9}, {3.839517229708441*^9, 
   3.83951725644874*^9}, 3.83951739469419*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"ac578d29-c6d4-45cb-8ed0-bc9949fcdc5b"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "munfl"}], "]"}]], "Input",
 CellChangeTimes->{{3.8395183465189333`*^9, 3.8395183558657*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"e83c3a25-5dcd-4e7c-814f-12991a239d2e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dt", "=", 
  RowBox[{"ParallelTable", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Off", "[", 
      RowBox[{"General", "::", "munfl"}], "]"}], ";", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"b", "=", "2."}], "}"}], ",", 
       RowBox[{"ReIm", "/@", 
        RowBox[{"calcstr2", "[", 
         RowBox[{"b", ",", "70", ",", "\[Theta]"}], "]"}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", "0.", ",", 
      RowBox[{"\[Pi]", "/", "4"}], ",", 
      RowBox[{"\[Pi]", "/", "400"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.839561602357821*^9, 3.839561604374125*^9}, {
  3.839562326213847*^9, 3.839562358585404*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"f4c8ef49-bebd-4b5a-b4bb-09f3d764f4ae"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.015854416565250377`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.061310893916534805`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1318692359773849`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.22336862061182755`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.3325134242404124`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.44814724410677875`", ",", "0"}], "}"}], ",", 
             TemplateBox[{"25"},
              "OutputSizeLimit`Skeleton"], ",", 
             RowBox[{"{", 
              RowBox[{"10.825950385445573`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"11.845595458654948`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"12.9709910179383`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"14.377732766153652`", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"16.165700588563155`", ",", "0"}], "}"}]}], "}"}], ",", 
           
           TemplateBox[{"99"},
            "OutputSizeLimit`Skeleton"], ",", 
           RowBox[{"{", 
            TemplateBox[{"1"},
             "OutputSizeLimit`Skeleton"], "}"}]}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          PaneBox[
           TagBox[
            TooltipBox[
             StyleBox[
              StyleBox[
               DynamicBox[ToBoxes[
                 FEPrivate`FrontEndResource[
                 "FEStrings", "sizeBriefExplanation"], StandardForm],
                ImageSizeCache->{56., {2., 7.}}],
               StripOnInput->False,
               DynamicUpdating->True,
               LineSpacing->{1, 2},
               LineIndent->0,
               LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLText",
              StripOnInput->False],
             StyleBox[
              DynamicBox[
               ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
                StandardForm]], DynamicUpdating -> True, LineIndent -> 0, 
              LinebreakAdjustments -> {1., 100, 0, 0, 0}, 
              LineSpacing -> {1, 2}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Dynamic[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
              DynamicUpdating -> True, LineIndent -> 0, 
              LinebreakAdjustments -> {1., 100, 0, 0, 0}, 
              LineSpacing -> {1, 2}], "Tooltip"]& ],
           Alignment->Center,
           BaselinePosition->Baseline,
           ImageSize->{Automatic, {25, Full}}], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{49., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{49., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 10, 16537474745930621205, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{55., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{55., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 10, 16537474745930621205, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{41., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            OutputSizeLimit`Defer, 10, 16537474745930621205, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{75., {0., 7.}}],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True,
              LineSpacing->{1, 2},
              LineIndent->0,
              LinebreakAdjustments->{1., 100, 0, 0, 0}], "OSLControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, {25, Full}}],
           Appearance->None,
           BaselinePosition->Baseline,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Advanced"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
     GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    BaseStyle->"OutputSizeLimit",
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  If[16537474745930621205 === $SessionID, 
   Out[10], Message[
     MessageName[Syntax, "noinfoker"]]; Missing["NotAvailable"]; 
   Null]]], "Output",
 CellChangeTimes->{3.839562321796496*^9, 3.839562448260621*^9, 
  3.839580914683609*^9, 3.839911642106821*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"f68a265d-095c-4052-8728-c55b318cadf6"]
}, Open  ]],

Cell["Define the pole positions (extracted from the data)", "Text",
 CellChangeTimes->{{3.8399114483182583`*^9, 3.839911463422488*^9}, {
  3.839911767093322*^9, 
  3.839911767372982*^9}},ExpressionUUID->"327f82de-e5ef-492a-a8b3-\
5dc5aee962f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r1", "=", 
   RowBox[{"{", 
    RowBox[{"0.46500691163166424`", ",", 
     RowBox[{"-", "0.004631270369681475`"}]}], "}"}]}], ";", 
  RowBox[{"i1", "=", 
   RowBox[{"IntegerPart", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"ArcTan", "@@", "r1"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "/", "400"}], ")"}]}], "/", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.839561784619576*^9, 3.8395617924476213`*^9}, {
  3.839561865176736*^9, 3.839561984949472*^9}, {3.839562838293874*^9, 
  3.839562838637496*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"b3735668-6590-49e0-8248-360629170b24"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"r2", "=", 
   RowBox[{"{", 
    RowBox[{"0.820732320958304`", ",", 
     RowBox[{"-", "0.6592846372988528`"}]}], "}"}]}], ";", 
  RowBox[{"i2", "=", 
   RowBox[{"IntegerPart", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"ArcTan", "@@", "r2"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "/", "400"}], ")"}]}], "/", "2"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.839561797144866*^9, 3.839561823783721*^9}, {
  3.839561966908547*^9, 3.8395619817176437`*^9}, {3.839562015402067*^9, 
  3.839562016681258*^9}, {3.8395628412457447`*^9, 3.839562841340886*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"81a26b3c-57e7-43db-a328-02ded7dcec98"],

Cell[BoxData["43"], "Output",
 CellChangeTimes->{3.839562466114497*^9, 3.839562855287407*^9, 
  3.83958091480031*^9, 3.839911642290255*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"5ce3c217-63f7-4571-8e5f-43e9563eb9c4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"r3", "=", 
   RowBox[{"{", 
    RowBox[{"0.5797805520274913`", ",", 
     RowBox[{"-", "1.3203056529283825`"}]}], "}"}]}], ";", 
  RowBox[{"i3", "=", 
   RowBox[{"IntegerPart", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"ArcTan", "@@", "r3"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", "/", "400"}], ")"}]}], "/", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.83956185156047*^9, 3.839561858088237*^9}, {
  3.839561970786478*^9, 3.8395620117622633`*^9}, {3.839562851062085*^9, 
  3.839562851149095*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"4aab48c8-e861-4279-b4d1-79b2fa7bfe7a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", "1.6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.5"}], ",", "0.17"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True"}], "}"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"Offset", "[", "10", "]"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"FontSize", "\[Rule]", "24"}], "]"}]}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}], " ", ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Re(E)\>\"", ",", "\"\<Im(E)\>\""}], "}"}]}], " ", ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"\"\<\[Theta]=\>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"i", "-", "1"}], ")"}], " ", 
                 RowBox[{"\[Pi]", "/", "400."}]}], ",", "0.01"}], "]"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
          RowBox[{"FontColor", "\[Rule]", "Black"}], ",", " ", 
          RowBox[{"FontSize", "\[Rule]", "30"}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", ">", " ", "i1"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Circle", "[", 
             RowBox[{"r1", ",", "0.02"}], "]"}], ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"r1", "+", 
                RowBox[{"{", 
                 RowBox[{"0.1", ",", 
                  RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
               RowBox[{"r1", "+", 
                RowBox[{"{", 
                 RowBox[{"0.01", ",", 
                  RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", ">", " ", 
           RowBox[{"i2", "+", "5"}]}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Circle", "[", 
             RowBox[{"r2", ",", "0.02"}], "]"}], ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"r2", "+", 
                RowBox[{"{", 
                 RowBox[{"0.1", ",", 
                  RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
               RowBox[{"r2", "+", 
                RowBox[{"{", 
                 RowBox[{"0.01", ",", 
                  RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", ">", " ", 
           RowBox[{"i3", "+", "6"}]}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Circle", "[", 
             RowBox[{"r3", ",", "0.02"}], "]"}], ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"r3", "+", 
                RowBox[{"{", 
                 RowBox[{"0.1", ",", 
                  RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
               RowBox[{"r3", "+", 
                RowBox[{"{", 
                 RowBox[{"0.01", ",", 
                  RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}]}],
          "]"}]}], "}"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "dt", "]"}], ",", "1"}], "}"}], ",", 
   RowBox[{"DisplayAllSteps", "\[Rule]", "True"}], ",", 
   RowBox[{"AnimationRate", "\[Rule]", "3"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.839561609431061*^9, 3.839561655882387*^9}, {
   3.8395617004509363`*^9, 3.839561751399825*^9}, {3.8395620325107803`*^9, 
   3.8395622147720957`*^9}, {3.8395623101691113`*^9, 3.839562311272793*^9}, {
   3.839562768606373*^9, 3.839562769814458*^9}, {3.839562811657763*^9, 
   3.8395628175077868`*^9}, {3.83956289454277*^9, 3.8395629059125566`*^9}, {
   3.839562994942774*^9, 3.839563038875155*^9}, {3.839563577599442*^9, 
   3.8395636178093443`*^9}, {3.8395642537978067`*^9, 
   3.8395643744132223`*^9}, {3.839564702020565*^9, 3.8395647181442537`*^9}, {
   3.8395647797230167`*^9, 3.839564782807178*^9}, {3.839564818243001*^9, 
   3.839564827560746*^9}, {3.8395650994271317`*^9, 3.839565107316427*^9}, {
   3.839565252859625*^9, 3.839565297932106*^9}, {3.839565573358891*^9, 
   3.839565575361063*^9}, {3.839565836806397*^9, 3.839565875304092*^9}, {
   3.839565985423499*^9, 3.839566106266687*^9}, {3.839566137608425*^9, 
   3.839566163966034*^9}, {3.8395662080007153`*^9, 3.8395662753133*^9}, {
   3.839566838899067*^9, 3.839566915105298*^9}, {3.839566945275764*^9, 
   3.839566971992221*^9}, {3.8395670078645163`*^9, 3.839567035436019*^9}, {
   3.83956707704068*^9, 3.8395670996606407`*^9}, {3.83956713393784*^9, 
   3.839567181741213*^9}, 3.839567228694511*^9, {3.839911498892537*^9, 
   3.839911507752097*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"f6e58df9-8153-4063-8221-252978731ce8"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$$ = 93, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`i$$], 1, 101, 1}}, Typeset`size$$ = {
    576., {274., 278.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`i$$ = 1}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        ListPlot[
         Part[$CellContext`dt, $CellContext`i$$], 
         PlotRange -> {{-0.2, 1.6}, {-1.5, 0.17}}, Frame -> True, 
         Axes -> {True, True}, AxesOrigin -> {0, 0}, AspectRatio -> Automatic,
          PlotMarkers -> {Automatic, 
           Offset[10]}, ImageSize -> Large, LabelStyle -> 
         Directive[FontSize -> 24], FrameStyle -> Directive[Thick, Black], 
         FrameTicksStyle -> Directive[Thick, Black], 
         FrameLabel -> {"Re(E)", "Im(E)"}, PlotLabel -> Style[
           StringJoin["\[Theta]=", 
            ToString[
             NumberForm[
              Round[($CellContext`i$$ - 1) (Pi/400.), 0.01], {3, 2}]]], 
           FontColor -> Black, FontSize -> 30]], 
        Graphics[{Red, 
          If[$CellContext`i$$ > $CellContext`i1, {
            Circle[$CellContext`r1, 0.02], 
            
            Arrow[{$CellContext`r1 + {0.1, -0.1}, $CellContext`r1 + {
               0.01, -0.01}}]}, {}], 
          If[$CellContext`i$$ > $CellContext`i2 + 5, {
            Circle[$CellContext`r2, 0.02], 
            
            Arrow[{$CellContext`r2 + {0.1, -0.1}, $CellContext`r2 + {
               0.01, -0.01}}]}, {}], 
          If[$CellContext`i$$ > $CellContext`i3 + 6, {
            Circle[$CellContext`r3, 0.02], 
            
            Arrow[{$CellContext`r3 + {0.1, -0.1}, $CellContext`r3 + {
               0.01, -0.01}}]}]}]], 
      "Specifications" :> {{$CellContext`i$$, 1, 101, 1, DisplayAllSteps -> 
         True, AnimationRate -> 3, AnimationRunning -> False, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{623., {310., 316.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.839564277861902*^9, {3.839564354342779*^9, 3.8395643750739594`*^9}, {
   3.8395647034308968`*^9, 3.8395647188310413`*^9}, 3.839564828883548*^9, 
   3.8395651422547607`*^9, {3.8395652609392757`*^9, 3.839565298290393*^9}, {
   3.839565851686955*^9, 3.839565876197769*^9}, {3.839565987478631*^9, 
   3.8395661070862637`*^9}, 3.839566139394424*^9, 3.839566209204047*^9, 
   3.8395662437003727`*^9, 3.839566276112172*^9, 3.839566884445383*^9, {
   3.8395669171794167`*^9, 3.839566972388997*^9}, {3.839567011010067*^9, 
   3.8395670366851673`*^9}, {3.839567081425264*^9, 3.839567100410304*^9}, 
   3.8395671826304083`*^9, 3.8395672310304937`*^9, 3.839580914948147*^9, 
   3.839911642337409*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"ea50f021-fe61-417f-91cc-9e2b0dd58c0b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export as video", "Section",
 CellChangeTimes->{{3.839911522055278*^9, 
  3.839911525047028*^9}},ExpressionUUID->"6c9e326b-b66e-4ab2-ad69-\
5dacc1148558"],

Cell[BoxData[
 RowBox[{
  RowBox[{"anim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"dt", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.2"}], ",", "1.6"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.5"}], ",", "0.17"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"Axes", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"True", ",", "True"}], "}"}]}], ",", 
         RowBox[{"AxesOrigin", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"PlotMarkers", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", 
            RowBox[{"Offset", "[", "10", "]"}]}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"FontSize", "\[Rule]", "24"}], "]"}]}], ",", 
         RowBox[{"FrameStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Thick", ",", "Black"}], "]"}]}], " ", ",", 
         RowBox[{"FrameTicksStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Re(E)\>\"", ",", "\"\<Im(E)\>\""}], "}"}]}], " ", ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\[Theta]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"i", "-", "1"}], ")"}], " ", 
                   RowBox[{"\[Pi]", "/", "400."}]}], ",", "0.01"}], "]"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"3", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
            RowBox[{"FontColor", "\[Rule]", "Black"}], ",", " ", 
            RowBox[{"FontSize", "\[Rule]", "30"}]}], "]"}]}]}], "]"}], ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", ">", " ", "i1"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Circle", "[", 
               RowBox[{"r1", ",", "0.02"}], "]"}], ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r1", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.1", ",", 
                    RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
                 RowBox[{"r1", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.01", ",", 
                    RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", ">", " ", 
             RowBox[{"i2", "+", "5"}]}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Circle", "[", 
               RowBox[{"r2", ",", "0.02"}], "]"}], ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r2", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.1", ",", 
                    RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
                 RowBox[{"r2", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.01", ",", 
                    RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", ">", " ", 
             RowBox[{"i3", "+", "6"}]}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Circle", "[", 
               RowBox[{"r3", ",", "0.02"}], "]"}], ",", 
              RowBox[{"Arrow", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r3", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.1", ",", 
                    RowBox[{"-", "0.1"}]}], "}"}]}], ",", 
                 RowBox[{"r3", "+", 
                  RowBox[{"{", 
                   RowBox[{"0.01", ",", 
                    RowBox[{"-", "0.01"}]}], "}"}]}]}], "}"}], "]"}]}], 
             "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "dt", "]"}], ",", "1"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.839565644343421*^9, 3.839565660395944*^9}, {
   3.8395663279402246`*^9, 3.839566347112352*^9}, 3.839567243272794*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"bfe70eb8-833e-42da-b431-74e6d59c6b7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
  RowBox[{"Export", "[", 
   RowBox[{"\"\<file.mp4\>\"", ",", "anim", ",", 
    RowBox[{"FrameRate", "\[Rule]", "10"}], ",", 
    RowBox[{"VideoEncoding", "\[Rule]", "\"\<MJPEG\>\""}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.839564888391588*^9, 3.8395649130238543`*^9}, {
   3.83956537706068*^9, 3.8395654172720547`*^9}, {3.839565470651615*^9, 
   3.839565471721527*^9}, {3.83956552063587*^9, 3.839565533041355*^9}, 
   3.8395656714912367`*^9, {3.839566654005677*^9, 3.839566668075754*^9}, {
   3.839580141143384*^9, 3.839580143807341*^9}, {3.8395807590506487`*^9, 
   3.839580764600799*^9}, {3.839580898968361*^9, 3.839580913870014*^9}, {
   3.839581073904395*^9, 3.839581074559764*^9}, {3.839581541536167*^9, 
   3.839581542919649*^9}},
 CellLabel->"In[39]:=",
 CellID->1516078609,ExpressionUUID->"02205e95-8712-47d4-88aa-d5f98f420ad9"],

Cell[BoxData["\<\"file.mp4\"\>"], "Output",
 CellChangeTimes->{
  3.839564934944564*^9, 3.839565318116551*^9, {3.83956540531701*^9, 
   3.8395654211742897`*^9}, 3.8395654775027933`*^9, {3.839565523154272*^9, 
   3.8395655437506437`*^9}, 3.839565682964995*^9, 3.839566359724082*^9, 
   3.8395666767580442`*^9, 3.839567258525981*^9, 3.839580920143187*^9, 
   3.8395810837662287`*^9, 3.839581552106216*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"47832faf-055d-46f8-bba0-07aa728a1445"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<file.mov\>\"", ",", "anim", ",", 
   RowBox[{"FrameRate", "\[Rule]", "10"}], ",", 
   RowBox[{"VideoEncoding", "\[Rule]", "\"\<MJPEG\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8395811335055723`*^9, 3.839581144355597*^9}, {
  3.839581555272545*^9, 3.839581566517791*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"1c48bd53-0cd9-42a9-9fff-37b57017b95b"],

Cell[BoxData["\<\"file.mov\"\>"], "Output",
 CellChangeTimes->{3.839581154030198*^9, 3.839581575859906*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"a8f3d214-57d6-4011-86d0-083b6e7d2016"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{807, 911},
WindowMargins->{{Automatic, -857}, {-107, Automatic}},
FrontEndVersion->"12.2 for Linux x86 (64-bit) (December 12, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"554c4e28-df4a-4017-a21d-df2486d0fc27"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 258, 4, 160, "Title",ExpressionUUID->"62ebb54d-6d01-4714-8bde-6b65eb5d9a46"],
Cell[841, 28, 252, 4, 53, "Subtitle",ExpressionUUID->"c6b7f60e-4d58-483a-b801-02770af1e00c"],
Cell[1096, 34, 831, 23, 46, "Text",ExpressionUUID->"1f1c5421-28fb-483f-bb02-4dc99bd6b04e"],
Cell[CellGroupData[{
Cell[1952, 61, 174, 3, 67, "Section",ExpressionUUID->"8e81c612-c136-4c4b-b0d7-b730fa7a38f7"],
Cell[CellGroupData[{
Cell[2151, 68, 907, 26, 54, "Input",ExpressionUUID->"2236accd-f04b-435a-b0be-1260b4af2428"],
Cell[3061, 96, 1237, 29, 76, "Output",ExpressionUUID->"27324179-7abd-4b0e-80d2-847ff0631a19"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4335, 130, 184, 3, 54, "Subsection",ExpressionUUID->"d0ba49e5-727d-40fc-a782-09f955d4ba9b"],
Cell[4522, 135, 169, 3, 35, "Text",ExpressionUUID->"b1111201-90a1-4a23-afd4-d54cb601910c"],
Cell[CellGroupData[{
Cell[4716, 142, 589, 16, 30, "Input",ExpressionUUID->"1e42b9c5-0e8b-4a98-9ffb-536725070328"],
Cell[5308, 160, 678, 12, 34, "Output",ExpressionUUID->"c05781cc-30cf-46ad-b672-f5eb1bde3ac2"]
}, Open  ]],
Cell[6001, 175, 732, 24, 41, "Text",ExpressionUUID->"437904fb-95e7-4b53-a4c2-7062e676bc2d"],
Cell[CellGroupData[{
Cell[6758, 203, 1060, 31, 46, "Input",ExpressionUUID->"7e0aaa1a-c545-4507-b84b-e840fb396b13"],
Cell[7821, 236, 905, 19, 49, "Output",ExpressionUUID->"7f506e7f-12a2-4c88-b578-c56fc52057a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8763, 260, 1724, 51, 127, "Input",ExpressionUUID->"efde600d-4a96-4c9c-bf29-2f1b05404f73"],
Cell[10490, 313, 902, 19, 49, "Output",ExpressionUUID->"e6c69685-97d9-4b70-a14d-57f9c3adfbb2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11429, 337, 2062, 63, 178, "Input",ExpressionUUID->"8fc47b2a-a884-4069-a09a-5867aebfb52f"],
Cell[13494, 402, 1253, 32, 56, "Output",ExpressionUUID->"2078d1ae-369f-42b6-8a61-29f42a11ec22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14784, 439, 561, 13, 53, "Input",ExpressionUUID->"1151d836-2f52-4ddb-8ae9-87924068ff39"],
Cell[15348, 454, 565, 9, 49, "Output",ExpressionUUID->"d5222f4d-bcb7-45f4-8d7e-c653a2607ae8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15950, 468, 1856, 58, 128, "Input",ExpressionUUID->"6b5e1311-f7e7-4649-88a3-0766b9792420"],
Cell[17809, 528, 687, 15, 49, "Output",ExpressionUUID->"24b4657f-ca85-4e1f-a3a3-3180c303158e"]
}, Open  ]],
Cell[18511, 546, 3353, 102, 130, "Text",ExpressionUUID->"b3a84ff0-4556-4131-85a7-f7a9f3efbfd8"],
Cell[21867, 650, 157, 3, 35, "Text",ExpressionUUID->"7004126b-0b7e-4cd1-b2f0-0607cbb423c6"],
Cell[CellGroupData[{
Cell[22049, 657, 622, 17, 30, "Input",ExpressionUUID->"8c5933de-0c93-4773-9f70-f7490c537240"],
Cell[22674, 676, 660, 13, 34, "Output",ExpressionUUID->"b311a96f-05b5-410d-9df9-cb9f5e6f03cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23371, 694, 316, 8, 32, "Input",ExpressionUUID->"f131dad6-f808-43de-895e-d77962cb4b37"],
Cell[23690, 704, 669, 13, 34, "Output",ExpressionUUID->"b62c248d-224c-4061-b5b8-9a81e38bb0ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24396, 722, 1324, 42, 76, "Input",ExpressionUUID->"fcf2ed12-aaff-42f9-8517-1db9d4901afb"],
Cell[25723, 766, 651, 13, 58, "Output",ExpressionUUID->"8eaa1ea3-dfba-4f6f-bf36-8ed5bab25b67"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26411, 784, 1629, 52, 128, "Input",ExpressionUUID->"b152ca7e-a27e-4495-a453-27c4257e4027"],
Cell[28043, 838, 603, 11, 58, "Output",ExpressionUUID->"be51ffbc-6337-4663-b229-22db4529dcdf"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[28695, 855, 177, 3, 38, "Subsection",ExpressionUUID->"bd1a983b-271e-4d66-8e36-d29705e49320"],
Cell[28875, 860, 579, 17, 62, "Text",ExpressionUUID->"92a9f7b9-7c61-4414-bad7-ff5b995ea4ce"],
Cell[29457, 879, 1626, 49, 114, "Input",ExpressionUUID->"702ca629-f8e4-4f3a-83dd-abb934ef64fc"],
Cell[31086, 930, 319, 7, 58, "Text",ExpressionUUID->"cea0d801-44d8-4868-bc63-63d6b7843fa4"],
Cell[CellGroupData[{
Cell[31430, 941, 281, 4, 30, "Input",ExpressionUUID->"70948c15-6e07-4712-9b34-51fb63a0d61a"],
Cell[31714, 947, 363, 5, 34, "Output",ExpressionUUID->"fae9488f-c63d-4920-8b81-586e9a593866"]
}, Open  ]],
Cell[32092, 955, 879, 19, 53, "Input",ExpressionUUID->"fae31b6e-a0a6-4e29-8b30-702bc1f47a13"],
Cell[32974, 976, 979, 27, 59, "Input",ExpressionUUID->"fe017a33-6577-4d7f-8b13-72ab6719fe30"],
Cell[CellGroupData[{
Cell[33978, 1007, 570, 15, 52, "Input",ExpressionUUID->"9671d86d-4fd7-41ab-b498-0719176f2180"],
Cell[34551, 1024, 458, 12, 41, "Output",ExpressionUUID->"16736475-e0e0-4242-b239-fa7ff08c579f"]
}, Open  ]],
Cell[35024, 1039, 282, 6, 30, "Input",ExpressionUUID->"3726e302-2df7-4cad-9a44-0180550503f4"],
Cell[35309, 1047, 183, 3, 35, "Text",ExpressionUUID->"a682d818-6ebb-4a9b-90f0-3aa47723dc05"],
Cell[35495, 1052, 2853, 69, 216, "Input",ExpressionUUID->"ac578d29-c6d4-45cb-8ed0-bc9949fcdc5b"],
Cell[38351, 1123, 234, 4, 30, "Input",ExpressionUUID->"e83c3a25-5dcd-4e7c-814f-12991a239d2e"],
Cell[CellGroupData[{
Cell[38610, 1131, 787, 20, 53, "Input",ExpressionUUID->"f4c8ef49-bebd-4b5a-b4bb-09f3d764f4ae"],
Cell[39400, 1153, 10237, 261, 143, "Output",ExpressionUUID->"f68a265d-095c-4052-8728-c55b318cadf6"]
}, Open  ]],
Cell[49652, 1417, 244, 4, 35, "Text",ExpressionUUID->"327f82de-e5ef-492a-a8b3-5dc5aee962f3"],
Cell[49899, 1423, 696, 19, 53, "Input",ExpressionUUID->"b3735668-6590-49e0-8248-360629170b24"],
Cell[CellGroupData[{
Cell[50620, 1446, 734, 19, 53, "Input",ExpressionUUID->"81a26b3c-57e7-43db-a328-02ded7dcec98"],
Cell[51357, 1467, 218, 3, 34, "Output",ExpressionUUID->"5ce3c217-63f7-4571-8e5f-43e9563eb9c4"]
}, Open  ]],
Cell[51590, 1473, 692, 19, 53, "Input",ExpressionUUID->"4aab48c8-e861-4279-b4d1-79b2fa7bfe7a"],
Cell[CellGroupData[{
Cell[52307, 1496, 6350, 150, 295, "Input",ExpressionUUID->"f6e58df9-8153-4063-8221-252978731ce8"],
Cell[58660, 1648, 4007, 79, 645, "Output",ExpressionUUID->"ea50f021-fe61-417f-91cc-9e2b0dd58c0b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62728, 1734, 160, 3, 67, "Section",ExpressionUUID->"6c9e326b-b66e-4ab2-ad69-5dacc1148558"],
Cell[62891, 1739, 5287, 133, 295, "Input",ExpressionUUID->"bfe70eb8-833e-42da-b431-74e6d59c6b7b"],
Cell[CellGroupData[{
Cell[68203, 1876, 956, 18, 53, "Input",ExpressionUUID->"02205e95-8712-47d4-88aa-d5f98f420ad9",
 CellID->1516078609],
Cell[69162, 1896, 482, 7, 34, "Output",ExpressionUUID->"47832faf-055d-46f8-bba0-07aa728a1445"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69681, 1908, 409, 7, 30, "Input",ExpressionUUID->"1c48bd53-0cd9-42a9-9fff-37b57017b95b"],
Cell[70093, 1917, 186, 2, 34, "Output",ExpressionUUID->"a8f3d214-57d6-4011-86d0-083b6e7d2016"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

